@@ -18,4 +18,4 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 #include <kwineffects.h>
-Q_LOGGING_CATEGORY(KWINEFFECTS, "kwineffects", QtCriticalMsg);
+Q_LOGGING_CATEGORY(KWINEFFECTS, "kwineffects", QtCriticalMsg)
