@@ -21,6 +21,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "magnifier_config.h"
 // KConfigSkeleton
 #include "magnifierconfig.h"
+#include <config-kwin.h>
 #include <kwineffects_interface.h>
 
 #include <QAction>
@@ -57,6 +58,7 @@ MagnifierEffectConfig::MagnifierEffectConfig(QWidget* parent, const QVariantList
 
     layout->addWidget(m_ui);
 
+    MagnifierConfig::instance(KWIN_CONFIG);
     addConfig(MagnifierConfig::self(), m_ui);
 
     connect(m_ui->editor, SIGNAL(keyChange()), this, SLOT(changed()));
