@@ -244,10 +244,8 @@ void PresentWindowsEffect::postPaintScreen()
         m_windowData.clear();
 
         foreach (EffectWindow * w, effects->stackingOrder()) {
-            if (w->isDock()) {
-                w->setData(WindowForceBlurRole, QVariant(false));
-                w->setData(WindowForceBackgroundContrastRole, QVariant(false));
-            }
+            w->setData(WindowForceBlurRole, QVariant(m_windowForceBlurRoleState.value(w, false)));
+            w->setData(WindowForceBackgroundContrastRole, QVariant(false));
         }
         effects->setActiveFullScreenEffect(NULL);
         effects->addRepaintFull();
@@ -967,7 +965,8 @@ void PresentWindowsEffect::rearrangeWindows()
         // Don't rearrange if the grid is the same size as what it was before to prevent
         // windows moving to a better spot if one was filtered out.
         if (m_layoutMode == LayoutRegularGrid &&
-                m_gridSizes[screen].columns * m_gridSizes[screen].rows &&
+                m_gridSizes[screen].columns &&
+                m_gridSizes[screen].rows &&
                 windows.size() < m_gridSizes[screen].columns * m_gridSizes[screen].rows &&
                 windows.size() > (m_gridSizes[screen].columns - 1) * m_gridSizes[screen].rows &&
                 windows.size() > m_gridSizes[screen].columns *(m_gridSizes[screen].rows - 1))
@@ -1408,9 +1407,6 @@ void PresentWindowsEffect::calculateWindowTransformationsNatural(EffectWindowLis
                 int xDiff = widthDiff / 2;  // Also move a bit in the direction of the enlarge, allows the
                 int yDiff = heightDiff / 2; // center windows to be enlarged if there is gaps on the side.
 
-                // heightDiff (and yDiff) will be re-computed after each successfull enlargement attempt
-                // so that the error introduced in the window's aspect ratio is minimized
-
                 // Attempt enlarging to the top-right
                 oldRect = *target;
                 target->setRect(target->x() + xDiff,
@@ -1420,11 +1416,8 @@ void PresentWindowsEffect::calculateWindowTransformationsNatural(EffectWindowLis
                                 );
                 if (isOverlappingAny(w, targets, borderRegion))
                     *target = oldRect;
-                else {
+                else
                     moved = true;
-                    heightDiff = heightForWidth(w, target->width() + widthDiff) - target->height();
-                    yDiff = heightDiff / 2;
-                }
 
                 // Attempt enlarging to the bottom-right
                 oldRect = *target;
@@ -1436,11 +1429,8 @@ void PresentWindowsEffect::calculateWindowTransformationsNatural(EffectWindowLis
                              );
                 if (isOverlappingAny(w, targets, borderRegion))
                     *target = oldRect;
-                else {
+                else
                     moved = true;
-                    heightDiff = heightForWidth(w, target->width() + widthDiff) - target->height();
-                    yDiff = heightDiff / 2;
-                }
 
                 // Attempt enlarging to the bottom-left
                 oldRect = *target;
@@ -1452,11 +1442,8 @@ void PresentWindowsEffect::calculateWindowTransformationsNatural(EffectWindowLis
                              );
                 if (isOverlappingAny(w, targets, borderRegion))
                     *target = oldRect;
-                else {
+                else
                     moved = true;
-                    heightDiff = heightForWidth(w, target->width() + widthDiff) - target->height();
-                    yDiff = heightDiff / 2;
-                }
 
                 // Attempt enlarging to the top-left
                 oldRect = *target;
@@ -1597,10 +1584,9 @@ void PresentWindowsEffect::setActive(bool active)
         setHighlightedWindow(effects->activeWindow());
 
         foreach (EffectWindow * w, effects->stackingOrder()) {
-            if (w->isDock()) {
-                w->setData(WindowForceBlurRole, QVariant(true));
-                w->setData(WindowForceBackgroundContrastRole, QVariant(true));
-            }
+            m_windowForceBlurRoleState[w] = w->data(WindowForceBlurRole).toBool();
+            w->setData(WindowForceBlurRole, QVariant(true));
+            w->setData(WindowForceBackgroundContrastRole, QVariant(true));
         }
     } else {
         m_needInitialSelection = false;
