@@ -83,6 +83,8 @@ ConfigurationModule::ConfigurationModule(QWidget *parent, const QVariantList &ar
 {
     m_proxyModel->setSourceModel(m_model);
     m_proxyModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
+    m_proxyModel->setSortCaseSensitivity(Qt::CaseInsensitive);
+    m_proxyModel->sort(0);
     connect(m_ui->filter, &QLineEdit::textChanged, m_proxyModel, &QSortFilterProxyModel::setFilterFixedString);
 
     m_quickView = new QQuickView(0);
@@ -99,7 +101,6 @@ ConfigurationModule::ConfigurationModule(QWidget *parent, const QVariantList &ar
 
     m_quickView->rootContext()->setContextProperty(QStringLiteral("decorationsModel"), m_proxyModel);
     updateColors();
-    m_quickView->rootContext()->setContextProperty("savedIndex", savedIndex());
     m_quickView->rootContext()->setContextProperty("_borderSizesIndex", 3); // 3 is normal
     m_quickView->rootContext()->setContextProperty("leftButtons", m_leftButtons);
     m_quickView->rootContext()->setContextProperty("rightButtons", m_rightButtons);
@@ -300,14 +301,6 @@ QVector< KDecoration2::DecorationButtonType > readDecorationButtons(const KConfi
     return buttonsFromString(config.readEntry(key, buttonsToString(defaultValue)));
 }
 
-int ConfigurationModule::savedIndex() const
-{
-    const KConfigGroup config = KSharedConfig::openConfig("kwinrc")->group(s_pluginName);
-    const QString plugin = config.readEntry("library", s_defaultPlugin);
-    const QString theme = config.readEntry("theme", s_defaultTheme);
-    return m_proxyModel->mapFromSource(m_model->findDecoration(plugin, theme)).row();
-}
-
 void ConfigurationModule::load()
 {
     s_loading = true;
@@ -318,6 +311,9 @@ void ConfigurationModule::load()
     const QVariant border = QVariant::fromValue(stringToSize(config.readEntry("BorderSize", s_borderSizeNormal)));
     m_ui->borderSizesCombo->setCurrentIndex(m_ui->borderSizesCombo->findData(border));
 
+    int themeIndex = m_proxyModel->mapFromSource(m_model->findDecoration(plugin, theme)).row();
+    m_quickView->rootContext()->setContextProperty("savedIndex", themeIndex);
+
     // buttons
     const auto &left = readDecorationButtons(config, "ButtonsOnLeft", QVector<KDecoration2::DecorationButtonType >{
         KDecoration2::DecorationButtonType::Menu,
