@@ -146,21 +146,48 @@ void AbstractPlatformContext::createContext(EGLContext shareContext)
     const QList<QByteArray> extensions = eglExtensions.split(' ');
     const bool haveRobustness = extensions.contains(QByteArrayLiteral("EGL_EXT_create_context_robustness"));
     const bool haveCreateContext = extensions.contains(QByteArrayLiteral("EGL_KHR_create_context"));
+    const bool haveContextPriority = extensions.contains(QByteArrayLiteral("EGL_IMG_context_priority"));
 
     std::vector<std::unique_ptr<AbstractOpenGLContextAttributeBuilder>> candidates;
     if (isOpenGLES()) {
+        if (haveCreateContext && haveRobustness && haveContextPriority) {
+            auto glesRobustPriority = std::unique_ptr<AbstractOpenGLContextAttributeBuilder>(new EglOpenGLESContextAttributeBuilder);
+            glesRobustPriority->setVersion(2);
+            glesRobustPriority->setRobust(true);
+            glesRobustPriority->setHighPriority(true);
+            candidates.push_back(std::move(glesRobustPriority));
+        }
         if (haveCreateContext && haveRobustness) {
             auto glesRobust = std::unique_ptr<AbstractOpenGLContextAttributeBuilder>(new EglOpenGLESContextAttributeBuilder);
             glesRobust->setVersion(2);
             glesRobust->setRobust(true);
             candidates.push_back(std::move(glesRobust));
         }
+        if (haveContextPriority) {
+            auto glesPriority = std::unique_ptr<AbstractOpenGLContextAttributeBuilder>(new EglOpenGLESContextAttributeBuilder);
+            glesPriority->setVersion(2);
+            glesPriority->setHighPriority(true);
+            candidates.push_back(std::move(glesPriority));
+        }
         auto gles = std::unique_ptr<AbstractOpenGLContextAttributeBuilder>(new EglOpenGLESContextAttributeBuilder);
         gles->setVersion(2);
         candidates.push_back(std::move(gles));
     } else {
         // Try to create a 3.1 core context
         if (m_format.majorVersion() >= 3 && haveCreateContext) {
+            if (haveRobustness && haveContextPriority) {
+                auto robustCorePriority = std::unique_ptr<AbstractOpenGLContextAttributeBuilder>(new EglContextAttributeBuilder);
+                robustCorePriority->setVersion(m_format.majorVersion(), m_format.minorVersion());
+                robustCorePriority->setRobust(true);
+                robustCorePriority->setForwardCompatible(true);
+                if (m_format.profile() == QSurfaceFormat::CoreProfile) {
+                    robustCorePriority->setCoreProfile(true);
+                } else if (m_format.profile() == QSurfaceFormat::CompatibilityProfile) {
+                    robustCorePriority->setCompatibilityProfile(true);
+                }
+                robustCorePriority->setHighPriority(true);
+                candidates.push_back(std::move(robustCorePriority));
+            }
             if (haveRobustness) {
                 auto robustCore = std::unique_ptr<AbstractOpenGLContextAttributeBuilder>(new EglContextAttributeBuilder);
                 robustCore->setVersion(m_format.majorVersion(), m_format.minorVersion());
@@ -173,6 +200,18 @@ void AbstractPlatformContext::createContext(EGLContext shareContext)
                 }
                 candidates.push_back(std::move(robustCore));
             }
+            if (haveContextPriority) {
+                auto corePriority = std::unique_ptr<AbstractOpenGLContextAttributeBuilder>(new EglContextAttributeBuilder);
+                corePriority->setVersion(m_format.majorVersion(), m_format.minorVersion());
+                corePriority->setForwardCompatible(true);
+                if (m_format.profile() == QSurfaceFormat::CoreProfile) {
+                    corePriority->setCoreProfile(true);
+                } else if (m_format.profile() == QSurfaceFormat::CompatibilityProfile) {
+                    corePriority->setCompatibilityProfile(true);
+                }
+                corePriority->setHighPriority(true);
+                candidates.push_back(std::move(corePriority));
+            }
             auto core = std::unique_ptr<AbstractOpenGLContextAttributeBuilder>(new EglContextAttributeBuilder);
             core->setVersion(m_format.majorVersion(), m_format.minorVersion());
             core->setForwardCompatible(true);
@@ -183,7 +222,12 @@ void AbstractPlatformContext::createContext(EGLContext shareContext)
             }
             candidates.push_back(std::move(core));
         }
-
+        if (haveRobustness && haveCreateContext && haveContextPriority) {
+            auto robustPriority = std::unique_ptr<AbstractOpenGLContextAttributeBuilder>(new EglContextAttributeBuilder);
+            robustPriority->setRobust(true);
+            robustPriority->setHighPriority(true);
+            candidates.push_back(std::move(robustPriority));
+        }
         if (haveRobustness && haveCreateContext) {
             auto robust = std::unique_ptr<AbstractOpenGLContextAttributeBuilder>(new EglContextAttributeBuilder);
             robust->setRobust(true);
