@@ -18,17 +18,19 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 #include "virtualkeyboard.h"
+#include "virtualkeyboard_dbus.h"
 #include "input.h"
+#include "keyboard_input.h"
 #include "utils.h"
 #include "screens.h"
 #include "wayland_server.h"
 #include "workspace.h"
+#include "xkb.h"
 
 #include <KWayland/Server/display.h>
 #include <KWayland/Server/seat_interface.h>
 #include <KWayland/Server/textinput_interface.h>
 
-#include <KKeyServer>
 #include <KStatusNotifierItem>
 #include <KLocalizedString>
 
@@ -97,6 +99,12 @@ void VirtualKeyboard::init()
             setEnabled(!m_enabled);
         }
     );
+    connect(this, &VirtualKeyboard::enabledChanged, this, &VirtualKeyboard::updateSni);
+
+    auto dbus = new VirtualKeyboardDBus(this);
+    dbus->setEnabled(m_enabled);
+    connect(dbus, &VirtualKeyboardDBus::activateRequested, this, &VirtualKeyboard::setEnabled);
+    connect(this, &VirtualKeyboard::enabledChanged, dbus, &VirtualKeyboardDBus::setEnabled);
 
     if (waylandServer()) {
         // we can announce support for the text input interface
@@ -185,8 +193,7 @@ void VirtualKeyboard::setEnabled(bool enabled)
     }
     m_enabled = enabled;
     qApp->inputMethod()->update(Qt::ImQueryAll);
-
-    updateSni();
+    emit enabledChanged(m_enabled);
 
     // send OSD message
     QDBusMessage msg = QDBusMessage::createMethodCall(
@@ -409,12 +416,7 @@ bool VirtualKeyboard::eventFilter(QObject *o, QEvent *e)
         QKeyEvent *event = static_cast<QKeyEvent*>(e);
         if (event->nativeScanCode() == 0) {
             // this is a key composed by the virtual keyboard - we need to send it to the client
-            // TODO: proper xkb support in KWindowSystem needed
-            int sym = xkb_keysym_from_name(event->text().toUtf8().constData(), XKB_KEYSYM_NO_FLAGS);
-            if (sym == XKB_KEY_NoSymbol) {
-                // mapping from text failed, try mapping through KKeyServer
-                KKeyServer::keyQtToSymX(event->key(), &sym);
-            }
+            const auto sym = input()->keyboard()->xkb()->fromKeyEvent(event);
             if (sym != 0) {
                 if (waylandServer()) {
                     auto t = waylandServer()->seat()->focusedTextInput();
